package com.zhilian.online.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.utils.uuid.IdUtils;
import com.zhilian.common.redis.service.RedisService;
import com.zhilian.online.config.RabbitConfig;
import com.zhilian.online.constans.OnlineConstants;
import com.zhilian.online.domain.Gather;
import com.zhilian.online.domain.VehicleAccount;
import com.zhilian.online.domain.req.GatherRegReq;
import com.zhilian.online.mapper.OnlineLoadCenterMapper;
import com.zhilian.online.service.OnlineLoadCenterService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

/**
 * @version 1.0
 * @Author LiYuan
 * @description 车辆负载中心服务层
 * @date 2024/3/29  20:42
 */
@Service
@Slf4j
public class OnlineLoadCenterServiceImpl extends ServiceImpl<OnlineLoadCenterMapper, VehicleAccount> implements OnlineLoadCenterService {

    /**
     * 车辆负载中心数据层
     */
    @Autowired
    private OnlineLoadCenterMapper onlineLoadCenterMapper;

    /**
     * Redis服务
     */
    @Autowired
    private RedisService redisService;

    /**
     * RabbitMQ服务
     */
    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * @description: 车辆申请注解令牌接口, 仅限内网访问
     * @author: LiYuan
     * @param: vehicle
     * @return: Result<OnlineAccount>
     **/
    @Override
    public Result<String> applyForReg() {

        //生成一次性令牌
        String token = IdUtils.fastSimpleUUID();

        //将令牌信息缓存到Redis中
        redisService.setCacheObject(OnlineConstants.ONLINE_TOKEN_PREFIX , token, OnlineConstants.ONLINE_TOKEN_EXPIRE, TimeUnit.MINUTES);

        //将账户信息返回客户端
        return Result.success(token);
    }


    /**
     * @description: 节点上线成功
     * @author: LiYuan
     * @param: Gather
     * @return: Result
     **/
    @Override
    public Result regGather(Gather gather) {
//        //判断登录令牌是否过期,一致
//        if (redisService.hasKey(OnlineConstants.ONLINE_TOKEN_PREFIX + gather.getClientId())) {
//            return Result.error("令牌已过期");
//        }

        //为该节点创建负载均衡缓存
        if (redisService.hasKey(OnlineConstants.ONLINE_TOKEN_PREFIX + gather.getClientId())) {
            redisService.deleteObject(OnlineConstants.ONLINE_TOKEN_PREFIX + gather.getClientId());
        }
        redisService.setCacheZsetValue(OnlineConstants.ONLINE_TOKEN_PREFIX + gather.getClientId(), gather, 0.0);

//        //向RabbitMQ||RocketMQ发送30s延迟消息,确保后续节点上线
//        rabbitTemplate.convertAndSend(RabbitConfig.DELAY_EXCHANGE_NAME, RabbitConfig.DELAY_ROUTING_KEY, JSON.toJSONString(gather));

        return Result.success("节点上线");
    }


}
